# natholi
____

A package allowing you to get national holidays for 200+ countries around the world. Based on [Calendarific API](https://calendarific.com/).

## Features

- displays in a dataframe national holiday data for a given country (holiday name, description, date)

## Example

```
import natholi

# get national holidays for Algeria
result = natholi.national_holidays('Algeria', CALENDARIFIC API KEY)
```
